powered by
Declares functions from base packages used in nonstandard evaluation or dynamic contexts across scf package functions. Ensures all used base functions are properly registered in the NAMESPACE.
scf