Learn R Programming

scf (version 1.0.5)

vcov.scf_model_result: Generic S3 Method: vcov.scf_model_result

Description

Reconstructs the pooled variance-covariance matrix of the model coefficients.

Usage

# S3 method for scf_model_result
vcov(object, ...)

Value

Returns the variance-covariance matrix from the internal pooling object if available, or stops with an error if the model object doesn't retain the raw pooled variance.

Arguments

object

An object of class 'scf_model_result'.

...

Not used.

Details

NOTE: The pooled variance matrix is NOT stored directly, only the coefficients and SEs. This method is typically skipped in favour of direct SE access or custom pooling, but is included here to provide a complete S3 interface.